@@ -1,13 +1,13 @@
 package CGI::Session::Driver::mysql;
 
-# $Id: mysql.pm 415 2008-06-16 14:40:45Z markstos $
+# $Id: mysql.pm 420 2008-07-08 01:23:06Z markstos $
 
 use strict;
 use Carp;
 use CGI::Session::Driver::DBI;
 
 @CGI::Session::Driver::mysql::ISA       = qw( CGI::Session::Driver::DBI );
-$CGI::Session::Driver::mysql::VERSION   = '4.31';
+$CGI::Session::Driver::mysql::VERSION   = '4.33';
 
 sub _mk_dsnstr {
     my ($class, $dsn) = @_;
@@ -47,18 +47,17 @@ sub store {
     croak "store(): usage error" unless $sid && $datastr;
 
     my $dbh = $self->{Handle};
-    $dbh->do("REPLACE INTO " . $self->table_name . " ($self->{IdColName}, $self->{DataColName}) VALUES(?, ?)", undef, $sid, $datastr)
+    $dbh->do("INSERT INTO " . $self->table_name .
+			 " ($self->{IdColName}, $self->{DataColName}) VALUES(?, ?) ON DUPLICATE KEY UPDATE $self->{DataColName} = ?",
+			 undef, $sid, $datastr, $datastr)
         or return $self->set_error( "store(): \$dbh->do failed " . $dbh->errstr );
     return 1;
 }
 
 
-# If the table name hasn't been defined yet, check this location for 3.x compatibility
 sub table_name {
     my $self = shift;
-    unless (defined $self->{TableName}) {
-        $self->{TableName} = $CGI::Session::MySQL::TABLE_NAME;
-    }
+
     return  $self->SUPER::table_name(@_);
 }
 
@@ -122,9 +121,19 @@ B<mysql> driver supports all the arguments documented in L<CGI::Session::Driver:
 
 =head2 BACKWARDS COMPATIBILITY
 
-For backwards compatibility, you can also set the table like this before calling C<new()>. However, it is not recommended because it can cause conflicts in a persistent environment. 
+As of V 4.30, the global variable $CGI::Session::MySQL::TABLE_NAME cannot be used to set the session
+table's name.
 
-    $CGI::Session::MySQL::TABLE_NAME = 'my_sessions';
+This is due to changes in CGI::Session::Driver's new() method, which now allows the table's name to be
+changed (as well as allowing both the 'id' column name and the 'a_session' column name to be changed).
+
+See the documentation for CGI::Session::Driver::DBI for details.
+
+In particular, the new syntax for C<new()> applies to all database drivers, whereas the old - and bad -
+global variable method only applied to MySQL.
+
+Alternately, call $session -> table_name('new_name') just after creating the session object if you wish to
+change the session table's name.
 
 =head1 LICENSING
 
